<?php

namespace App\Form;

use App\Entity\IndividualData;
use App\Entity\Territory;
use App\Type\DreamType;
use App\Type\ProjectBoostType;
use App\Type\ProjectInspiringType;
use App\Type\RevoltType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class IndividualDataForm extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('territory', EntityType::class, [
                'label' => 'Je suis un.e citoyen.ne du',
                'class' => Territory::class,
                'expanded' => true,
                'multiple' => false,
            ])
            ->add('revolt', CollectionType::class, [
                'entry_type' => RevoltType::class,
                'entry_options' => [
                    'context' => $options['context'],
                    'label' => false,
                ],
                'label' => 'Qu’est ce qui vous révolte sur votre territoire ?',
                'allow_add' => true,
                'allow_delete' => true,
                'by_reference' => false,
            ])
            ->add('dream', CollectionType::class, [
                'entry_type' => DreamType::class,
                'entry_options' => [
                    'context' => $options['context'],
                    'label' => false,
                ],
                'label' => 'Quel est votre ou vos rêves pour votre territoire ?',
                'allow_add' => true,
                'allow_delete' => true,
                'by_reference' => false,
            ])
            ->add('projectBoost', CollectionType::class, [
                'entry_type' => ProjectBoostType::class,
                'entry_options' => [
                    'context' => $options['context'],
                    'label' => false,
                ],
                'label' => 'Quelles initiatives locales meriteraient à votre avis d’être davantage soutenues ?',
                'allow_add' => true,
                'allow_delete' => true,
                'by_reference' => false,
            ])
            ->add('projectInspiring', CollectionType::class, [
                'entry_type' => ProjectInspiringType::class,
                'entry_options' => [
                    'context' => $options['context'],
                    'label' => false,
                ],
                'label' => 'Quelles initiatives que vous avez pû découvrir ailleurs auraient à votre avis toute leur place sur votre territoire ?',
                'allow_add' => true,
                'allow_delete' => true,
                'by_reference' => false,
            ])
            ->add('save', SubmitType::class, [
                'attr' => ['class' => 'save button-yellow'],
                'label' => 'ENVOYER'
            ]);
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
            [
                'data_class' => IndividualData::class,
                "context" => "backend"
            ]
        );
    }
}
